#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Créé le Sat Apr 2 2022

@auteur: David ALBERTO
(www.astrolabe-science.fr)
"""
import matplotlib.pyplot as plt #Graphiques
import numpy as np #calculs sur les listes
import matplotlib as mpl#Normalisation des valeurs
import matplotlib.colorbar as cbar#barres de couleurs
from mpl_toolkits.axes_grid1 import make_axes_locatable#positionner les barres de couleurs
import pandas as pd#création et gestion d'un DataFrame

plt.rcParams["font.family"] = "Roboto"
echelle_points=8


planetes={'nom' : [
                "Mercure",
                "Vénus",
                "Terre",
                "Mars",
                "Jupiter",
                "Saturne",
                "Uranus",
                "Neptune"
                ],
            'rayon' : [2440e3,
                       6052e3,
                       6371e3,
                       3390e3,
                       69911e3,
                       58232e3,
                       25362e3,
                       24622e3],
            'masse' : [0.33e24,
                       4.87e24,
                       5.97e24,
                       0.64e24,
                       1899e24,
                       568e24,
                       86.8e24,
                       102.4e24
                       ]
    }

planetes = pd.DataFrame(planetes)

R=planetes.rayon
m=planetes.masse
noms=planetes.nom

G=6.67e-11#constante de gravitation universelle

#gamme de couleurs choisie (colormap) :
cmap=plt.get_cmap('YlGn')
"""
Les colormaps sont à choisir parmi les séquentiels :
'Greys', 'Purples', 'Blues', 'Greens', 'Oranges', 'Reds',
'YlOrBr', 'YlOrRd', 'OrRd', 'PuRd', 'RdPu', 'BuPu',
'GnBu', 'PuBu', 'YlGnBu', 'PuBuGn', 'BuGn', 'YlGn'
"""
xR=R[0:4]
yR=m[0:4]
xG=R[4:]
yG=m[4:]
gR=G*np.array(yR)/np.array(xR)**2# calcul de la constante de pesanteur
gG=G*np.array(yG)/np.array(xG)**2
#normalisation de la gamme de valeurs :
norm = mpl.colors.Normalize(vmin=min(gR),vmax=max(gG)) 

fig=plt.figure(figsize=(29.7/2.54,21/2.54),tight_layout=True)
plt.suptitle(r"\sffamily \bfseries Pesanteur à la surface des planètes, selon leur rayon et leur masse", fontsize=16, usetex=True)
# %%%%%%%%%%%%%%% Planètes rocheuses
ax1=plt.subplot(221)
ax1.set_title("Planètes rocheuses",y=0.9)
plt.xlabel("rayon (m)")
plt.ylabel("masse (kg)")
ax1.set_ylim(0,6.5e24)

x_offset=5e4
y_offset=0.1e24
ax1.scatter(xR,yR,s=echelle_points*gR, edgecolor='k',c=cmap(norm(gR)))

for N in planetes.index[0:4] :
    ax1.text(xR[N]+x_offset, yR[N]+y_offset,noms[N][0:3],fontsize=7)

ax1.text(0.99,0.01,"Les diamètres et les couleurs des points reflètent la pesanteur.",transform=ax1.transAxes,fontsize=6,ha='right')
# %%%%%%%%%%%%%%%% Planètes gazeuses

ax2=plt.subplot(223)
ax2.set_title("Planètes gazeuses", y=0.9)
plt.xlabel("rayon (m)")
plt.ylabel("masse (kg)")
ax2.set_ylim(0,2.1e27)
x_offset=1e5
y_offset=0.1e27

ax2.scatter(xG,yG,s= echelle_points*gG, edgecolor='k', c=cmap(norm(gG)))

for N in planetes.index[4:] :
    if N==7:
        x_offset=-10*x_offset
    ax2.text(xG[N]+x_offset, yG[N]+y_offset, noms[N][0:3],fontsize=7)

ax2.text(0.99,0.01,"Les diamètres et les couleurs des points reflètent la pesanteur.",transform=ax2.transAxes,fontsize=6,ha='right')

#tracé de la barre de couleurs :
divider = make_axes_locatable(ax2)
cax = divider.append_axes('bottom', size='8%', pad=0.5)
cb=cbar.ColorbarBase(cax, cmap=cmap, norm=norm, orientation='horizontal')
cax.set_title("constante de pesanteur g",y=-3.0)

# %%%%%%%%%%%%%%%%%% Axe Nord-Est : texte
ax3=plt.subplot(222)
ax3.set_xticks([])
ax3.set_yticks([])

plt.text(0.01,0.98,
         r"\begin{minipage}{12.7cm}"
           r"\large La constante de pesanteur g à la surface d'une planète est donnée par : \[g=\frac{G \cdot m}{R^2}\]~"
           r" où $m$ est la masse de la planète, et $R$ son rayon ($G=6.67\cdot 10^{-11}~SI)$."
           r"\\\\Mercure et Mars ont des pesanteurs très comparables~:\\"
           r"En effet, leurs rayons sont dans un rapport proche de $\sqrt{2}$, et leurs masses dans un rapport proche de 2,~"
           r"ces deux effets se compensant, avec une concordance de 99.5\%."
           r" \\Le couple Vénus - Terre présente un effet similaire, avec une compensation moindre (90\%). Pour Vénus - Uranus : 98.5\%."
           r"\\Pour le couple Saturne - Neptune, la compensation est assez bonne (99\%), avec un rapport de~"
           r"2,37 pour les rayons, et de 5,57 pour les masses"
           r"~($2.37^2\simeq 5.6$)."
           r"\end{minipage}",
           usetex=True,
          va='top', transform=ax3.transAxes)


# %%%%%%%%%%%%%%%%%% Axe Sud-Est
ax4=plt.subplot(224)
ax4.set_yticks([])
ax4.set_title(r"Rapport $\frac{m}{R^2}$ pour les planètes",y=1.02)

rapport=np.array(m)/np.array(R)**2

ax4.scatter(range(len(noms)),rapport,ec='k',c='crimson')

ax4.set_xticks(range(len(noms)))
ax4.set_xticklabels([nom[0:3] for nom in noms])

fig.text(0.99,0.02,"D. Alberto (www.astrolabe-science.fr)",transform=fig.transFigure,fontsize=6,ha='right')
fig.savefig("PesanteurPlanetes.png",dpi=200)
fig.savefig("PesanteurPlanetes.pdf",dpi=200)
